@@ -8,7 +8,6 @@ from collections.abc import Iterable
 class ModelContainer(object):
 
     """Helper class that holds the model parameters required for computations in all use cases."""
-
     def __init__(self, y_true, p_var, p_grp, model_type, model_name = 'auto', y_pred=None, y_prob=None, y_train=None, protected_features_cols=None, train_op_name="fit",
                  predict_op_name ="predict", feature_imp=None, sample_weight=None, pos_label=[[1]], neg_label=None, x_train=None, x_test=None, model_object=None):
         """
@@ -28,7 +27,7 @@ class ModelContainer(object):
 
                 Customer Marketing: "uplift" or "propensity" or "reject"
                 Credit Scoring: "credit"
-                Base Clasee: "default"
+                Base Class: "default"
 
         Instance Attributes
         --------------------
@@ -87,6 +86,7 @@ class ModelContainer(object):
                 VeritasError object to save errors
 
         pos_label2 : array, default=None
+                Encoded pos_label value
         """
         self.x_train = x_train
         self.x_test = x_test
@@ -101,11 +101,11 @@ class ModelContainer(object):
         self.train_op_name = train_op_name
         self.predict_op_name = predict_op_name
         self.feature_imp = feature_imp
-        self.sample_weight = sample_weight       
+        self.sample_weight = sample_weight
         self.model_name = model_name
         self.model_type = model_type
         if self.model_name == 'auto':
-            self.model_name = model_type   
+            self.model_name = model_type
         self.pos_label = pos_label
         self.neg_label = neg_label
         self.pos_label2 = None
@@ -134,20 +134,25 @@ class ModelContainer(object):
             check_p_grp=dict.fromkeys(p_var)
 
         # Dictionary for input data
-        if protected_features_cols is None and type(self.x_test) == pd.DataFrame:
-            self.protected_features_cols = self.x_test[p_var]
+        if protected_features_cols is None:
+            if type(self.x_test) == pd.DataFrame:
+                self.protected_features_cols = self.x_test[p_var]
+            else:
+                self.err.push('type_error', var_name='x_test', given=str(type(str)), expected=str(pd.DataFrame),
+                            function_name='ModelContainer')
+                self.err.pop()
+
         for var in check_p_grp.keys():
             check_p_grp[var] = self.protected_features_cols[var].unique()
             
         NoneType = type(None)
 
-
         # Dictionary for expected data type
         # if value range is a tuple, will be considered as a numerical range
         # if value range is a list/set of str, will be considered as a collection of available values
         self._input_validation_lookup = {
             "y_true": [(list, np.ndarray, pd.Series), ],
-            "y_train": [(NoneType, list, np.ndarray, pd.Series), check_y_label], 
+            "y_train": [(NoneType, list, np.ndarray, pd.Series), ], 
             "y_pred": [(NoneType, list, np.ndarray, pd.Series), check_y_label], 
             "y_prob": [(NoneType, list, np.ndarray, pd.Series, pd.DataFrame), (-0.01,1.01)],
             "p_var":  [(list,), str],
@@ -167,8 +172,10 @@ class ModelContainer(object):
         
         check_datatype(self)
         
+        #if model name is longer than 20 characters, will keep the first 20 only
         self.model_name = self.model_name[0:20]
 
+        #convert to numpy array for easier processing
         self.y_true = np.array(self.y_true)
         if self.y_pred is not None :
             self.y_pred = np.array(self.y_pred)
@@ -351,8 +358,7 @@ class ModelContainer(object):
         
         if self.y_train is not None :
             if set(self.y_true) != set(self.y_train):
-                err_.append(['value_error', "y_train labels", str(set(self.y_train)), str(set(self.y_true))])                
-
+                self.y_train = None
         if err_ == []:
             return successMsg
         else:
@@ -361,8 +367,6 @@ class ModelContainer(object):
                             function_name="check_label_consistency")            
             self.err.pop()
 
-
-
     def check_label_length(self):
         """
         Checks if the length of labels is correct according to the model_type
@@ -452,7 +456,6 @@ class ModelContainer(object):
         ----------------
         clone_obj : object
         """
-        
         clone_obj = ModelContainer(y_true = y_true, p_var = self.p_var, p_grp = self.p_grp, x_train= self.x_train,  x_test = self.x_test, model_object = model_object, model_type = self.model_type, model_name = "clone", y_pred=y_pred, y_prob=y_prob, y_train = y_train, protected_features_cols=self.protected_features_cols, train_op_name=train_op_name,
                  predict_op_name = predict_op_name, feature_imp=self.feature_imp, sample_weight=self.sample_weight, pos_label=pos_label, neg_label=neg_label)
         
